@@ -138,6 +138,7 @@ EXTENSIONS = {
     'markdown': {'text', 'markdown'},
     'md': {'text', 'markdown'},
     'mdx': {'text', 'mdx'},
+    'meson': {'text', 'meson'},
     'mib': {'text', 'mib'},
     'mjs': {'text', 'javascript'},
     'mk': {'text', 'makefile'},
@@ -147,6 +148,7 @@ EXTENSIONS = {
     'modulemap': {'text', 'modulemap'},
     'mscx': {'text', 'xml', 'musescore'},
     'mscz': {'binary', 'zip', 'musescore'},
+    'mustache': {'text', 'mustache'},
     'myst': {'text', 'myst'},
     'ngdoc': {'text', 'ngdoc'},
     'nim': {'text', 'nim'},
@@ -169,6 +171,7 @@ EXTENSIONS = {
     'pm': {'text', 'perl'},
     'png': {'binary', 'image', 'png'},
     'po': {'text', 'pofile'},
+    'pom': {'pom', 'text', 'xml'},
     'pp': {'text', 'puppet'},
     'prisma': {'text', 'prisma'},
     'properties': {'text', 'java-properties'},
@@ -220,6 +223,7 @@ EXTENSIONS = {
     'tac': {'text', 'twisted', 'python'},
     'tar': {'binary', 'tar'},
     'tex': {'text', 'tex'},
+    'textproto': {'text', 'textproto'},
     'tf': {'text', 'terraform'},
     'tfvars': {'text', 'terraform'},
     'tgz': {'binary', 'gzip'},
@@ -333,6 +337,8 @@ NAMES = {
     'LICENSE': EXTENSIONS['txt'],
     'MAINTAINERS': EXTENSIONS['txt'],
     'Makefile': EXTENSIONS['mk'],
+    'meson.build': EXTENSIONS['meson'],
+    'meson_options.txt': EXTENSIONS['meson'],
     'makefile': EXTENSIONS['mk'],
     'NEWS': EXTENSIONS['txt'],
     'NOTICE': EXTENSIONS['txt'],
@@ -341,6 +347,7 @@ NAMES = {
     'Pipfile.lock': EXTENSIONS['json'],
     'PKGBUILD': {'text', 'bash', 'pkgbuild', 'alpm'},
     'poetry.lock': EXTENSIONS['toml'],
+    'pom.xml': EXTENSIONS['pom'],
     'pylintrc': EXTENSIONS['ini'] | {'pylintrc'},
     'README': EXTENSIONS['txt'],
     'Rakefile': EXTENSIONS['rb'],
